#[non_exhaustive]pub enum StateValue<D = InMemoryDB>where
D: DB,{
Null,
Cell(Sp<AlignedValue, D>),
Map(HashMap<AlignedValue, StateValue<D>, D>),
Array(Array<StateValue<D>, D>),
BoundedMerkleTree(MerkleTree<(), D>),
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Null
Cell(Sp<AlignedValue, D>)
Map(HashMap<AlignedValue, StateValue<D>, D>)
Array(Array<StateValue<D>, D>)
A fixed size array, with 0 <= len <= 16. The upper 5 bits of the
argument to the new opcode specify the length at creation time. The
underlying storage::Array type is not fixed length, but in the VM we
only allow size preserving operations.
BoundedMerkleTree(MerkleTree<(), D>)
Merkle tree with 0 < height <= 32.
Implementations