pub struct TranscriptVersion {
pub major: u8,
pub minor: u8,
}Fields
major: u8minor: u8Trait Implementations
Sourceimpl Clone for TranscriptVersion
impl Clone for TranscriptVersion
Sourcefn clone(&self) -> TranscriptVersion
fn clone(&self) -> TranscriptVersion
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TranscriptVersion
impl Debug for TranscriptVersion
Sourceimpl Deserializable for TranscriptVersion
impl Deserializable for TranscriptVersion
Sourceimpl<'de> Deserialize<'de> for TranscriptVersion
impl<'de> Deserialize<'de> for TranscriptVersion
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for TranscriptVersion
impl PartialEq for TranscriptVersion
Sourceimpl Serializable for TranscriptVersion
impl Serializable for TranscriptVersion
Sourceimpl Serialize for TranscriptVersion
impl Serialize for TranscriptVersion
Sourceimpl<_D: DB> Storable<_D> for TranscriptVersion
impl<_D: DB> Storable<_D> for TranscriptVersion
Sourcefn children(&self) -> Vec<ArenaKey<<_D as DB>::Hasher>>
fn children(&self) -> Vec<ArenaKey<<_D as DB>::Hasher>>
Provides an iterator over hashes of child
Sps, if any. These hashes
will be passed back into from_binary_repr when deserializing.Sourcefn to_binary_repr<W: Write>(&self, writer: &mut W) -> Result<(), Error>
fn to_binary_repr<W: Write>(&self, writer: &mut W) -> Result<(), Error>
Serializes self, omitting any children.
Sourcefn from_binary_repr<R: Read>(
reader: &mut R,
_child_hashes: &mut impl Iterator<Item = ArenaKey<<_D as DB>::Hasher>>,
loader: &impl Loader<_D>,
) -> Result<Self, Error>
fn from_binary_repr<R: Read>( reader: &mut R, _child_hashes: &mut impl Iterator<Item = ArenaKey<<_D as DB>::Hasher>>, loader: &impl Loader<_D>, ) -> Result<Self, Error>
Instantiates self, given hashes of any children, and loader that loads
children given their hash.
Sourceimpl Tagged for TranscriptVersion
impl Tagged for TranscriptVersion
Sourcefn tag() -> Cow<'static, str>
fn tag() -> Cow<'static, str>
Retrieves the tag of
Self. Returns a [Cow] as type arguments require allocation, but no
allocation is preferred.Sourcefn tag_unique_factor() -> String
fn tag_unique_factor() -> String
A decomposition of this tag into primitive types (any type whose representation is not
defined through other types), tuples (via
(a,b)), and sum types (via [a,b]). Read moreimpl Eq for TranscriptVersion
impl StructuralPartialEq for TranscriptVersion